==> zio-aws-backup_2.13-5.17.123.1-sources.jar: zio/aws/backup/model/ListProtectedResourcesResponse.scala <==
package zio.aws.backup.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListProtectedResourcesResponse(
    results: Option[Iterable[zio.aws.backup.model.ProtectedResource]] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse = {
    import ListProtectedResourcesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse
      .builder()
      .optionallyWith(
        results.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.results)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.backup.model.ListProtectedResourcesResponse.ReadOnly =
    zio.aws.backup.model.ListProtectedResourcesResponse.wrap(buildAwsValue())
}
object ListProtectedResourcesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backup.model.ListProtectedResourcesResponse =
      zio.aws.backup.model.ListProtectedResourcesResponse(
        results.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def results: Option[List[zio.aws.backup.model.ProtectedResource.ReadOnly]]
    def nextToken: Option[String]
    def getResults: ZIO[Any, AwsError, List[
      zio.aws.backup.model.ProtectedResource.ReadOnly
    ]] = AwsError.unwrapOptionField("results", results)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse
  ) extends zio.aws.backup.model.ListProtectedResourcesResponse.ReadOnly {
    override val results
        : Option[List[zio.aws.backup.model.ProtectedResource.ReadOnly]] = scala
      .Option(impl.results())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.backup.model.ProtectedResource.wrap(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse
  ): zio.aws.backup.model.ListProtectedResourcesResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-backup_2.13-5.19.31.4-sources.jar: zio/aws/backup/model/ListProtectedResourcesResponse.scala <==
package zio.aws.backup.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListProtectedResourcesResponse(
    results: Optional[Iterable[zio.aws.backup.model.ProtectedResource]] =
      Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse = {
    import ListProtectedResourcesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse
      .builder()
      .optionallyWith(
        results.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.results)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.backup.model.ListProtectedResourcesResponse.ReadOnly =
    zio.aws.backup.model.ListProtectedResourcesResponse.wrap(buildAwsValue())
}
object ListProtectedResourcesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backup.model.ListProtectedResourcesResponse =
      zio.aws.backup.model.ListProtectedResourcesResponse(
        results.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def results: Optional[List[zio.aws.backup.model.ProtectedResource.ReadOnly]]
    def nextToken: Optional[String]
    def getResults: ZIO[Any, AwsError, List[
      zio.aws.backup.model.ProtectedResource.ReadOnly
    ]] = AwsError.unwrapOptionField("results", results)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse
  ) extends zio.aws.backup.model.ListProtectedResourcesResponse.ReadOnly {
    override val results
        : Optional[List[zio.aws.backup.model.ProtectedResource.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.results())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.backup.model.ProtectedResource.wrap(item)
          }.toList
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.backup.model.ListProtectedResourcesResponse
  ): zio.aws.backup.model.ListProtectedResourcesResponse.ReadOnly = new Wrapper(
    impl
  )
}
